@@ -15,6 +15,7 @@
 
 import testtools
 
+from glanceclient.tests.unit.v2 import base
 from glanceclient.tests import utils
 from glanceclient.v2 import metadefs
 
@@ -444,8 +445,9 @@ schema_fixtures = {
                     },
                     "updated_at": {
                         "type": "string",
+                        "readOnly": True,
                         "description": "Date and time of the last namespace "
-                                       "modification (READ-ONLY)",
+                                       "modification",
                         "format": "date-time"
                     },
                     "visibility": {
@@ -512,8 +514,8 @@ schema_fixtures = {
                     },
                     "created_at": {
                         "type": "string",
-                        "description": "Date and time of namespace creation "
-                                       "(READ-ONLY)",
+                        "readOnly": True,
+                        "description": "Date and time of namespace creation ",
                         "format": "date-time"
                     },
                     "namespace": {
@@ -541,83 +543,79 @@ class TestNamespaceController(testtools.TestCase):
         super(TestNamespaceController, self).setUp()
         self.api = utils.FakeAPI(data_fixtures)
         self.schema_api = utils.FakeSchemaAPI(schema_fixtures)
-        self.controller = metadefs.NamespaceController(self.api,
-                                                       self.schema_api)
+        self.controller = base.BaseController(self.api, self.schema_api,
+                                              metadefs.NamespaceController)
 
     def test_list_namespaces(self):
-        namespaces = list(self.controller.list())
-
+        namespaces = self.controller.list()
         self.assertEqual(2, len(namespaces))
         self.assertEqual(NAMESPACE1, namespaces[0]['namespace'])
         self.assertEqual(NAMESPACE2, namespaces[1]['namespace'])
 
     def test_list_namespaces_paginate(self):
-        namespaces = list(self.controller.list(page_size=1))
-
+        namespaces = self.controller.list(page_size=1)
         self.assertEqual(2, len(namespaces))
         self.assertEqual(NAMESPACE7, namespaces[0]['namespace'])
         self.assertEqual(NAMESPACE8, namespaces[1]['namespace'])
 
     def test_list_with_limit_greater_than_page_size(self):
-        namespaces = list(self.controller.list(page_size=1, limit=2))
+        namespaces = self.controller.list(page_size=1, limit=2)
         self.assertEqual(2, len(namespaces))
         self.assertEqual(NAMESPACE7, namespaces[0]['namespace'])
         self.assertEqual(NAMESPACE8, namespaces[1]['namespace'])
 
     def test_list_with_marker(self):
-        namespaces = list(self.controller.list(marker=NAMESPACE6, page_size=2))
+        namespaces = self.controller.list(marker=NAMESPACE6, page_size=2)
         self.assertEqual(2, len(namespaces))
         self.assertEqual(NAMESPACE7, namespaces[0]['namespace'])
         self.assertEqual(NAMESPACE8, namespaces[1]['namespace'])
 
     def test_list_with_sort_dir(self):
-        namespaces = list(self.controller.list(sort_dir='asc', limit=1))
+        namespaces = self.controller.list(sort_dir='asc', limit=1)
         self.assertEqual(1, len(namespaces))
         self.assertEqual(NAMESPACE1, namespaces[0]['namespace'])
 
     def test_list_with_sort_dir_invalid(self):
         # NOTE(TravT): The clients work by returning an iterator.
         # Invoking the iterator is what actually executes the logic.
-        ns_iterator = self.controller.list(sort_dir='foo')
-        self.assertRaises(ValueError, next, ns_iterator)
+        self.assertRaises(ValueError, self.controller.list, sort_dir='foo')
 
     def test_list_with_sort_key(self):
-        namespaces = list(self.controller.list(sort_key='created_at', limit=1))
+        namespaces = self.controller.list(sort_key='created_at', limit=1)
         self.assertEqual(1, len(namespaces))
         self.assertEqual(NAMESPACE1, namespaces[0]['namespace'])
 
     def test_list_with_sort_key_invalid(self):
         # NOTE(TravT): The clients work by returning an iterator.
         # Invoking the iterator is what actually executes the logic.
-        ns_iterator = self.controller.list(sort_key='foo')
-        self.assertRaises(ValueError, next, ns_iterator)
+        self.assertRaises(ValueError, self.controller.list, sort_key='foo')
 
     def test_list_namespaces_with_one_resource_type_filter(self):
-        namespaces = list(self.controller.list(
+        namespaces = self.controller.list(
             filters={
                 'resource_types': [RESOURCE_TYPE1]
             }
-        ))
+        )
 
         self.assertEqual(1, len(namespaces))
         self.assertEqual(NAMESPACE3, namespaces[0]['namespace'])
 
     def test_list_namespaces_with_multiple_resource_types_filter(self):
-        namespaces = list(self.controller.list(
+        namespaces = self.controller.list(
             filters={
                 'resource_types': [RESOURCE_TYPE1, RESOURCE_TYPE2]
             }
-        ))
+        )
 
         self.assertEqual(1, len(namespaces))
         self.assertEqual(NAMESPACE4, namespaces[0]['namespace'])
 
     def test_list_namespaces_with_visibility_filter(self):
-        namespaces = list(self.controller.list(
+        namespaces = self.controller.list(
             filters={
                 'visibility': 'private'
             }
-        ))
+        )
 
         self.assertEqual(1, len(namespaces))
         self.assertEqual(NAMESPACE5, namespaces[0]['namespace'])
